spacepy.toolbox.linspace — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »

# spacepy.toolbox.linspace

`spacepy.toolbox.` `linspace`(min, max, num, **kwargs)

  Returns linear-spaced bins. Same as numpy.linspace except works with datetime and is faster

  Parameters: | min : float, datetime minimum value max : float, datetime maximum value num : integer number of linear spaced bins
  Returns: | out : array linear-spaced bins from min to max in a numpy array
  Other Parameters:
  | kwargs : dict additional keywords passed into matplotlib.dates.num2date

  See also

  `geomspace`, `logspace`

  Notes

  This function works on both numbers and datetime objects

  Examples

      >>> import spacepy.toolbox as tb
      >>> tb.linspace(1, 10, 4)
      array([  1.,   4.,   7.,  10.])

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »